﻿using Dto;
using Entities;
using Model.OrderCriteria;
using Shared;
using Shared.Mapper;

namespace API.Service;

public class LessonDataServiceApi(ILessonService<LessonEntity> lessonService) : ILessonService<LessonDTO>
{
    public IEnumerable<LessonDTO> GetLessons(int page, int number, LessonOrderCriteria orderCriteria)
    {
        var lessonsEntities = lessonService.GetLessons(page, number, orderCriteria);
        return lessonsEntities.Select(e => e.FromEntityToDTOGet()).ToList();
    }

    public LessonDTO GetLessonById(int id) => lessonService.GetLessonById(id).FromEntityToDTOGet();

    public LessonDTO GetLessonByTitle(string title) => lessonService.GetLessonByTitle(title).FromEntityToDTOGet();

    public bool DeleteLesson(int id) => lessonService.DeleteLesson(id);

    public LessonDTO UpdateLesson(int id, LessonDTO lesson) =>
        lessonService.UpdateLesson(id, lesson.FromDTOToEntity()).FromEntityToDTOGet();

    public LessonDTO UpdateLesson(int id, LessonEntity lesson) =>
        lessonService.UpdateLesson(id, lesson).FromEntityToDTOPost();

    public LessonDTO CreateLesson(int id, string title, string lastPublisher, DateOnly? lastEdit) =>
        lessonService.CreateLesson(id, title, lastPublisher, lastEdit).FromEntityToDTOPost();
}